# https://raw.githubusercontent.com/NixOS/nixpkgs/nixos-24.05/pkgs/development/tools/misc/babeltrace/default.nix

let
  pkgs = import <nixpkgs> { };
in
  pkgs.stdenv.mkDerivation rec {
    pname = "babeltrace2";
    version = "2.0.6";

    src = pkgs.fetchurl {
      url = "https://www.efficios.com/files/babeltrace/${pname}-${version}.tar.bz2";
      sha256 = "1jajxjlj7p25j2awjlnddxayp6ac4c3cfb7kj5dhppj2wrspw750";
    };

    # The pre-generated ./configure script uses an old autoconf version which
    # breaks cross-compilation (replaces references to malloc with rpl_malloc).
    # Re-generate with nixpkgs's autoconf. This requires glib to be present in
    # nativeBuildInputs for its m4 macros to be present.
    nativeBuildInputs = with pkgs; [ autoreconfHook glib pkg-config ];
    buildInputs = with pkgs; [ glib libuuid popt elfutils ];

    # --enable-debug-info (default) requires the configure script to run host
    # executables to determine the elfutils library version, which cannot be done
    # while cross compiling.
    configureFlags = pkgs.lib.optional (pkgs.stdenv.hostPlatform != pkgs.stdenv.buildPlatform) "--disable-debug-info";

    meta = with pkgs.lib; {
      description = "Command-line tool and library to read and convert LTTng tracefiles";
      homepage = "https://www.efficios.com/babeltrace";
      license = licenses.mit;
      platforms = platforms.linux;
      maintainers = [ maintainers.bjornfor ];
    };
  }
